'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _axisUtils = require('../../utils/axis-utils');

var _scalesUtils = require('../../utils/scales-utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; } // Copyright (c) 2016 Uber Technologies, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

var LEFT = _axisUtils.ORIENTATION.LEFT;
var RIGHT = _axisUtils.ORIENTATION.RIGHT;
var TOP = _axisUtils.ORIENTATION.TOP;
var BOTTOM = _axisUtils.ORIENTATION.BOTTOM;


var propTypes = {
  width: _react2.default.PropTypes.number.isRequired,
  height: _react2.default.PropTypes.number.isRequired,
  orientation: _react2.default.PropTypes.oneOf([LEFT, RIGHT, TOP, BOTTOM]).isRequired
};

function _getTickTextAttributes(orientation) {
  var textAnchor = orientation === LEFT ? 'end' : orientation === RIGHT ? 'start' : 'middle';
  var dy = orientation === TOP ? '0' : orientation === BOTTOM ? '0.72em' : '0.32em';
  return {
    textAnchor: textAnchor,
    dy: dy
  };
}

function _getTickFormatFn(scale, tickTotal, tickFormat) {
  return !tickFormat ? scale.tickFormat ? scale.tickFormat(tickTotal) : function (v) {
    return v;
  } : tickFormat;
}

function AxisTicks(props) {
  var attr = props.attr;
  var orientation = props.orientation;
  var width = props.width;
  var height = props.height;
  var tickSize = props.tickSize;
  var tickPadding = props.tickPadding;
  var tickFormat = props.tickFormat;
  var tickTotal = props.tickTotal;
  var tickValues = props.tickValues;
  var _props$tickSizeInner = props.tickSizeInner;
  var tickSizeInner = _props$tickSizeInner === undefined ? tickSize : _props$tickSizeInner;
  var _props$tickSizeOuter = props.tickSizeOuter;
  var tickSizeOuter = _props$tickSizeOuter === undefined ? tickSize : _props$tickSizeOuter;


  var x = orientation === LEFT ? width : 0;
  var y = orientation === TOP ? height : 0;

  var isVertical = orientation === LEFT || orientation === RIGHT;
  var scale = (0, _scalesUtils.getAttributeScale)(props, attr);

  var wrap = orientation === LEFT || orientation === TOP ? -1 : 1;

  var values = (0, _axisUtils.getTickValues)(scale, tickTotal, tickValues);
  var tickFormatFn = _getTickFormatFn(scale, tickTotal, tickFormat);

  var tickXAttr = isVertical ? 'y' : 'x';
  var tickYAttr = isVertical ? 'x' : 'y';

  var ticks = values.map(function (v, i) {
    var _pathProps, _extends2;

    var pos = scale(v);
    var text = tickFormatFn(v);
    var pathProps = (_pathProps = {}, _defineProperty(_pathProps, tickXAttr + '1', pos), _defineProperty(_pathProps, tickXAttr + '2', pos), _defineProperty(_pathProps, tickYAttr + '1', -wrap * tickSizeOuter), _defineProperty(_pathProps, tickYAttr + '2', wrap * tickSizeInner), _pathProps);
    var textProps = _extends((_extends2 = {}, _defineProperty(_extends2, tickXAttr, pos), _defineProperty(_extends2, tickYAttr, wrap * (tickSizeOuter + tickPadding)), _extends2), _getTickTextAttributes(orientation));
    return _react2.default.createElement(
      'g',
      { key: i, className: 'rv-xy-plot__axis__tick' },
      _react2.default.createElement('line', _extends({}, pathProps, { className: 'rv-xy-plot__axis__tick__line' })),
      _react2.default.createElement(
        'text',
        _extends({}, textProps, { className: 'rv-xy-plot__axis__tick__text' }),
        text
      )
    );
  });

  return _react2.default.createElement(
    'g',
    {
      transform: 'translate(' + x + ', ' + y + ')',
      className: 'rv-xy-plot__axis__ticks' },
    ticks
  );
}

AxisTicks.displayName = 'AxisTicks';
AxisTicks.propTypes = propTypes;
AxisTicks.requiresSVG = true;

exports.default = AxisTicks;